<?php
/**
 * @package    Illumination
 * @version    1.0
 * @author     senlin (Piet Bos) <piet@senlinonline.com>
 * @copyright  Copyright (c) 2013, Piet Bos
 * @link       http://themehybrid.com/themes/illumination
 * @license:	GNU General Public License v2.0 or later
 * @license URI:http://www.gnu.org/licenses/gpl-2.0.html
 */

/* Add the child theme setup function to the 'after_setup_theme' hook. */
add_action( 'after_setup_theme', 'illumination_setup', 10 );

/**
 * Setup function.  All child themes should run their setup within this function.  The idea is to add/remove 
 * filters and actions after the parent theme has been set up.  This function provides you that opportunity.
 *
 * @since  0.1.0
 * @access public
 * @return void
 */
function illumination_setup() {

	/*
	 * Add a custom background to overwrite the defaults.
	 * @since 0.1.0
	 * @link http://codex.wordpress.org/Custom_Backgrounds
	 */
	add_theme_support(
		'custom-background',
		array(
			'default-color' => '330000',
			'default-image' => '%2$s/images/backgrounds/xmas-balls.jpg',
		)
	);

	/*
	 * Add a custom header to overwrite the defaults.
	 * @since 0.1.0
	 * @link http://codex.wordpress.org/Custom_Headers
	 */
	add_theme_support( 
		'custom-header', 
		array(
			'default-text-color' => 'CC3300',
			'default-image'      => '%2$s/images/headers/candles.jpg',
			'random-default'     => false
		)
	);
	
	/**
	 * Un-Register default Parent Theme headers for the child theme.
	 * @since 0.1.1
	 */
	unregister_default_headers(
		array( 'horizon', 'orange-burn', 'planets-blue', 'planet-burst', 'space-splatters' )
	);

	/*
	 * Registers default headers for the child theme.
	 * @since 0.1.0
	 * @link http://codex.wordpress.org/Function_Reference/register_default_headers
	 */
	register_default_headers(
		array(
			'candle' => array(
				'url'           => '%2$s/images/headers/candle.png',
				'thumbnail_url' => '%2$s/images/headers/candle-thumb.png',
				/* Translators: Header image description. */
				'description'   => __( 'Candle', 'illumination' )
			),
			'candles' => array(
				'url'           => '%2$s/images/headers/candles.jpg',
				'thumbnail_url' => '%2$s/images/headers/candles-thumb.jpg',
				/* Translators: Header image description. */
				'description'   => __( 'Candles', 'illumination' )
			)
		)
	);

	/* Register default background images. */
	add_filter( 'hybrid_default_backgrounds', 'illumination_default_backgrounds', 11 );
	
	/* Add a custom default color for the "primary" color option. */
	add_filter( 'theme_mod_color_primary', 'illumination_color_primary' );
}

/**
 * Registers custom backgrounds for the child theme.
 *
 * @since  0.1.0
 * @access public
 * @return void
 */
function illumination_default_backgrounds( $backgrounds ) {

	$_backgrounds = array(
		'blurry-lights' => array(
			'url'           => '%2$s/images/backgrounds/blurry-lights.jpg',
			'thumbnail_url' => '%2$s/images/backgrounds/blurry-lights-thumb.jpg',
		),
		'tealights' => array(
			'url'           => '%2$s/images/backgrounds/tealights.jpg',
			'thumbnail_url' => '%2$s/images/backgrounds/tealights-thumb.jpg',
		),
		'tealights-dark' => array(
			'url'           => '%2$s/images/backgrounds/tealights-dark.jpg',
			'thumbnail_url' => '%2$s/images/backgrounds/tealights-dark-thumb.jpg',
		),
		'tealights-green' => array(
			'url'           => '%2$s/images/backgrounds/tealights-green.jpg',
			'thumbnail_url' => '%2$s/images/backgrounds/tealights-green-thumb.jpg',
		),
		'tealights-orange' => array(
			'url'           => '%2$s/images/backgrounds/tealights-orange.jpg',
			'thumbnail_url' => '%2$s/images/backgrounds/tealights-orange-thumb.jpg',
		),
		'tealights-red' => array(
			'url'           => '%2$s/images/backgrounds/tealights-red.jpg',
			'thumbnail_url' => '%2$s/images/backgrounds/tealights-red-thumb.jpg',
		),
		'xmas-balls' => array(
			'url'           => '%2$s/images/backgrounds/xmas-balls.jpg',
			'thumbnail_url' => '%2$s/images/backgrounds/xmas-balls-thumb.jpg',
		),
	);

	return array_merge( $backgrounds, $_backgrounds );
}

/**
 * Add a default custom color for the theme's "primary" color option.  Users can overwrite this from the 
 * theme customizer, so we want to make sure to check that there's no value before returning our custom 
 * color.
 *
 * @since  0.1.0
 * @access public
 * @param  string  $hex
 * @return string
 */
function illumination_color_primary( $hex ) {
	return $hex ? $hex : 'CC3300';
}